@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2012 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2011 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -58,7 +58,12 @@ class ConfigModel(gtk.ListStore):
     def _fill_model(self):
         self.clear()
         for key in sorted(self._config.Settings):
-            fieldtype, default = self._config.Settings[key][:2]
+            # Do not show config settings starting with "_" in the UI
+            if key.startswith('_'):
+                continue
+
+            default = self._config.Settings[key]
+            fieldtype = type(default)
             value = getattr(self._config, key, default)
 
             if value == default:
@@ -73,7 +78,7 @@ class ConfigModel(gtk.ListStore):
     def _on_update(self, name, old_value, new_value):
         for row in self:
             if row[self.C_NAME] == name:
-                if new_value == self._config.Settings[name][1]:
+                if new_value == self._config.Settings[name]:
                     style = pango.STYLE_NORMAL
                 else:
                     style = pango.STYLE_ITALIC
@@ -125,24 +130,6 @@ class UIConfig(config.Config):
             setattr(self, name, togglebutton.get_active())
         togglebutton.connect('toggled', _togglebutton_toggled)
 
-    def connect_gtk_filechooser(self, name, filechooser, is_for_files=False):
-        assert name in self.Settings
-
-        # FIXME: can we determine "is_for_files" by consulting the filechooser?
-        if is_for_files:
-            # A FileChooser for a single file
-            filechooser.set_filename(getattr(self, name))
-        else:
-            # A FileChooser for a folder
-            filechooser.set_current_folder(getattr(self, name))
-
-        def _chooser_selection_changed(filechooser):
-            filename = filechooser.get_filename()
-            if filename is not None:
-                setattr(self, name, filename)
-
-        filechooser.connect('selection-changed', _chooser_selection_changed)
-
     def connect_gtk_window(self, window, config_prefix, show_window=False):
         x, y, width, height, maximized = map(lambda x: config_prefix+'_'+x, \
                 ('x', 'y', 'width', 'height', 'maximized'))
@@ -158,8 +145,8 @@ class UIConfig(config.Config):
             self.__ignore_window_events = True
 
             def _receive_configure_event(widget, event):
-                x_pos, y_pos = widget.get_position()
-                width_size, height_size = widget.get_size()
+                x_pos, y_pos = event.x, event.y
+                width_size, height_size = event.width, event.height
                 if not self.__ignore_window_events and not \
                        (hasattr(self, maximized) and getattr(self, maximized)):
                     setattr(self, x, x_pos)
@@ -186,6 +173,4 @@ class UIConfig(config.Config):
                 window.show()
             if getattr(self, maximized, False):
                 window.maximize()
-        else:
-            raise ValueError('Cannot connect %s', config_prefix, sender=self)
 
