@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2012 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2011 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -118,8 +118,6 @@ def draw_text_box_centered(ctx, widget, w_width, w_height, text, font_desc=None,
 
 
 def draw_text_pill(left_text, right_text, x=0, y=0, border=2, radius=14, font_desc=None):
-    if gpodder.ui.fremantle:
-        border += 3
     # Create temporary context to calculate the text size
     ctx = cairo.Context(cairo.ImageSurface(cairo.FORMAT_ARGB32, 1, 1))
 
@@ -250,38 +248,3 @@ def cairo_surface_to_pixbuf(s):
     pixbuf = pbl.get_pixbuf()
     return pixbuf
 
-def progressbar_pixbuf(width, height, percentage):
-    COLOR_BG = (.4, .4, .4, .4)
-    COLOR_FG = (.2, .9, .2, 1.)
-    COLOR_FG_HIGH = (1., 1., 1., .5)
-    COLOR_BORDER = (0., 0., 0., 1.)
-
-    surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, width, height)
-    ctx = cairo.Context(surface)
-
-    padding = int(float(width)/8.0)
-    bar_width = 2*padding
-    bar_height = height - 2*padding
-    bar_height_fill = bar_height*percentage
-
-    # Background
-    ctx.rectangle(padding, padding, bar_width, bar_height)
-    ctx.set_source_rgba(*COLOR_BG)
-    ctx.fill()
-
-    # Foreground
-    ctx.rectangle(padding, padding+bar_height-bar_height_fill, bar_width, bar_height_fill)
-    ctx.set_source_rgba(*COLOR_FG)
-    ctx.fill()
-    ctx.rectangle(padding+bar_width/3, padding+bar_height-bar_height_fill, bar_width/4, bar_height_fill)
-    ctx.set_source_rgba(*COLOR_FG_HIGH)
-    ctx.fill()
-
-    # Border
-    ctx.rectangle(padding-.5, padding-.5, bar_width+1, bar_height+1)
-    ctx.set_source_rgba(*COLOR_BORDER)
-    ctx.set_line_width(1.)
-    ctx.stroke()
-
-    return cairo_surface_to_pixbuf(surface)
-
