@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2012 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2011 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
 #
 
 import gtk
-
-from xml.sax import saxutils
+import cgi
 
 import gpodder
 
@@ -31,8 +30,6 @@ from gpodder.gtkui.interface.common import BuilderWidget
 
 
 class gPodderConfigEditor(BuilderWidget):
-    finger_friendly_widgets = ['btnShowAll', 'btnClose', 'configeditor']
-    
     def new(self):
         name_column = gtk.TreeViewColumn(_('Setting'))
         name_renderer = gtk.CellRendererText()
@@ -64,8 +61,6 @@ class gPodderConfigEditor(BuilderWidget):
 
         self.configeditor.set_model(self.filter)
         self.configeditor.set_rules_hint(True)
-        self.configeditor.get_selection().connect( 'changed',
-            self.on_configeditor_row_changed )
 
     def visible_func(self, model, iter, user_data=None):
         text = self.entryFilter.get_text().lower()
@@ -84,9 +79,9 @@ class gPodderConfigEditor(BuilderWidget):
 
         if not self._config.update_field(name, new_text):
             message = _('Cannot set %(field)s to %(value)s. Needed data type: %(datatype)s')
-            d = {'field': saxutils.escape(name),
-                 'value': saxutils.escape(new_text),
-                 'datatype': saxutils.escape(type_cute)}
+            d = {'field': cgi.escape(name),
+                 'value': cgi.escape(new_text),
+                 'datatype': cgi.escape(type_cute)}
             self.notification(message % d, _('Error setting option'))
 
     def value_toggled(self, renderer, path):
@@ -112,9 +107,3 @@ class gPodderConfigEditor(BuilderWidget):
     def on_gPodderConfigEditor_destroy(self, widget):
         self.model.stop_observing()
 
-    def on_configeditor_row_changed(self, treeselection):
-        model, iter = treeselection.get_selected()
-        if iter is not None:
-            option_name = self._config.get_description( model.get(iter, 0)[0] )
-            self.config_option_description_label.set_text(option_name)
-
