@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2012 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2011 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,12 +25,6 @@
 #
 
 
-try:
-    import dbus
-except ImportError:
-    # Import Mock D-Bus interfaces when D-Bus bindings are not installed
-    from gpodder.gui import dbus
-
 import gpodder
 import urllib
 
