@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2012 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2011 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -56,23 +56,23 @@ try:
 except ImportError:
     coverage = None
 
-if coverage is not None:
-    coverage.erase()
-    coverage.start()
+if __name__ == '__main__':
+    if coverage is not None:
+        coverage.erase()
+        coverage.start()
 
-result = runner.run(suite)
+    result = runner.run(suite)
 
-if not result.wasSuccessful():
-    sys.exit(1)
+    if not result.wasSuccessful():
+        sys.exit(1)
 
-if coverage is not None:
-    coverage.stop()
-    coverage.report(coverage_modules)
-    coverage.erase()
-
-if coverage is None:
-    print >>sys.stderr, """
-    No coverage reporting done (Python module "coverage" is missing)
-    Please install the python-coverage package to get coverage reporting.
-    """
+    if coverage is not None:
+        coverage.stop()
+        coverage.report(coverage_modules)
+        coverage.erase()
+    else:
+        print >>sys.stderr, """
+        No coverage reporting done (Python module "coverage" is missing)
+        Please install the python-coverage package to get coverage reporting.
+        """
 
