@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # gPodder - A media aggregator and podcast client
-# Copyright (c) 2005-2012 Thomas Perl and the gPodder Team
+# Copyright (c) 2005-2011 Thomas Perl and the gPodder Team
 #
 # gPodder is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,18 +24,18 @@
 import gpodder
 
 from gpodder import util
-from gpodder.liblogger import log
+
+import logging
+logger = logging.getLogger(__name__)
+
+try:
+    import simplejson as json
+except ImportError:
+    import json
 
 import re
 import urllib
 
-try:
-    # Python >= 2.6
-    from urlparse import parse_qs
-except ImportError:
-    # Python < 2.6
-    from cgi import parse_qs
-
 # See http://en.wikipedia.org/wiki/YouTube#Quality_and_codecs
 # Currently missing: the WebM 480p and 720 formats; 3GP profile
 supported_formats = [
@@ -50,11 +50,19 @@ supported_formats = [
 
 class YouTubeError(Exception): pass
 
-def get_real_download_url(url, preferred_fmt_id=18):
+def get_real_download_url(url, preferred_fmt_id=None):
+    # Default fmt_id when none preferred
+    if preferred_fmt_id is None:
+        preferred_fmt_id = 18
+
+    # For Maemo 5, we force fmt_id 5 for performance reasons
+    if gpodder.ui.fremantle and not gpodder.ui.harmattan:
+        preferred_fmt_id = 5
+
     vid = get_youtube_id(url)
     if vid is not None:
         page = None
-        url = 'http://www.youtube.com/get_video_info?&el=detailpage&video_id=' + vid
+        url = 'http://www.youtube.com/watch?v=' + vid
 
         while page is None:
             req = util.http_request(url, method='GET')
@@ -66,16 +74,14 @@ def get_real_download_url(url, preferred_fmt_id=18):
         # Try to find the best video format available for this video
         # (http://forum.videohelp.com/topic336882-1800.html#1912972)
         def find_urls(page):
-            r4 = re.search('.*&url_encoded_fmt_stream_map=([^&]+)&.*', page)
+            r4 = re.search('.*"url_encoded_fmt_stream_map"\:\s+"([^"]+)".*', page)
             if r4 is not None:
-                fmt_url_map = urllib.unquote(r4.group(1))
+                fmt_url_map = r4.group(1)
                 for fmt_url_encoded in fmt_url_map.split(','):
-                    video_info = parse_qs(fmt_url_encoded)
-                    yield int(video_info['itag'][0]), video_info['url'][0]
-            else:
-                error_info = parse_qs(page)
-                error_message = util.remove_html_tags(error_info['reason'][0])
-                raise YouTubeError('Cannot download video: %s' % error_message)
+                    video_info = dict(map(urllib.unquote, x.split('=', 1))
+                            for x in fmt_url_encoded.split('\\u0026'))
+
+                    yield int(video_info['itag']), video_info['url']
 
         fmt_id_url_map = sorted(find_urls(page), reverse=True)
         # Default to the highest fmt_id if we don't find a match below
@@ -87,12 +93,7 @@ def get_real_download_url(url, preferred_fmt_id=18):
         formats_available = set(fmt_id for fmt_id, url in fmt_id_url_map)
         fmt_id_url_map = dict(fmt_id_url_map)
 
-        if gpodder.ui.diablo:
-            # Hardcode fmt_id 5 for Maemo (for performance reasons) - we could
-            # also use 13 and 17 here, but the quality is very low then. There
-            # seems to also be a 6, but I could not find a video with that yet.
-            fmt_id = 5
-        elif gpodder.ui.fremantle:
+        if gpodder.ui.fremantle:
             # This provides good quality video, seems to be always available
             # and is playable fluently in Media Player
             if preferred_fmt_id == 5:
@@ -116,7 +117,7 @@ def get_real_download_url(url, preferred_fmt_id=18):
                 # If the format is available and preferred (or lower),
                 # use the given format for our fmt_id
                 if id in formats_available and seen_preferred:
-                    log('Found available YouTube format: %s (fmt_id=%d)', \
+                    logger.info('Found YouTube format: %s (fmt_id=%d)',
                             description, id)
                     fmt_id = id
                     break
@@ -151,7 +152,7 @@ def get_real_channel_url(url):
 
     if m is not None:
         next = 'http://www.youtube.com/rss/user/'+ m.group(1) +'/videos.rss'
-        log('YouTube link resolved: %s => %s', url, next)
+        logger.debug('YouTube link resolved: %s => %s', url, next)
         return next
 
     r = re.compile('http://(?:[a-z]+\.)?youtube\.com/profile?user=([a-z0-9]+)', re.IGNORECASE)
@@ -159,7 +160,7 @@ def get_real_channel_url(url):
 
     if m is not None:
         next = 'http://www.youtube.com/rss/user/'+ m.group(1) +'/videos.rss'
-        log('YouTube link resolved: %s => %s', url, next)
+        logger.debug('YouTube link resolved: %s => %s', url, next)
         return next
 
     return url
@@ -175,35 +176,33 @@ def get_real_cover(url):
         data = util.urlopen(api_url).read()
         match = re.search('<media:thumbnail url=[\'"]([^\'"]+)[\'"]/>', data)
         if match is not None:
-            log('YouTube userpic for %s is: %s', url, match.group(1))
+            logger.debug('YouTube userpic for %s is: %s', url, match.group(1))
             return match.group(1)
 
     return None
 
 def find_youtube_channels(string):
-    # FIXME: Make proper use of the YouTube API instead
-    # of screen-scraping the YouTube website
-    url = 'http://www.youtube.com/results?search_query='+ urllib.quote(string, '') +'&search_type=search_users&aq=f'
-
-    r = re.compile('>\s+<')
-    data = r.sub('><', util.urlopen(url).read())
-
-    r1 = re.compile('<a href="/user/([^"?]+)[^"]+"[^>]*>([^<]+)</a>')
-    m1 = r1.findall(data)
-
-    r2 = re.compile('\s+')
+    url = 'http://gdata.youtube.com/feeds/api/videos?alt=json&q=%s' % urllib.quote(string, '')
+    data = json.load(util.urlopen(url))
 
     class FakeImporter(object):
         def __init__(self):
             self.items = []
 
     result = FakeImporter()
-    found_users = []
-    for name, title in m1:
-        if name not in found_users:
-            found_users.append(name)
-            link = 'http://www.youtube.com/rss/user/'+ name +'/videos.rss'
-            result.items.append({'title': name, 'url': link, 'description': title})
+
+    seen_users = set()
+    for entry in data['feed']['entry']:
+        user = entry['author'][0]['name']['$t']
+        title = entry['title']['$t']
+        url = 'http://www.youtube.com/rss/user/%s/videos.rss' % user
+        if user not in seen_users:
+            result.items.append({
+                'title': user,
+                'url': url,
+                'description': title
+            })
+            seen_users.add(user)
 
     return result
 
